@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from flask import request
 from flask.views import MethodView
 from werkzeug import __version__ as werkzeug_version
 
-if werkzeug_version.split('.')[0] >= '2':
+if werkzeug_version.split(".")[0] >= "2":
     from werkzeug.wrappers import Response as BaseResponse
 else:
     from werkzeug.wrappers import BaseResponse
